@@ -6,7 +6,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -18,11 +18,6 @@
 // P2Pnat implementation written by Simon Horne <s.horne@packetizer.com>
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <h323pdu.h> 
 #include <h235auth.h>
@@ -528,8 +523,8 @@ class STUNClient   :  public  Job,
 	                          public PSTUNClient
 {
  public:
-	 STUNClient(GkClient * _client, const H323TransportAddress &);
-	~STUNClient();
+	STUNClient(GkClient * _client, const H323TransportAddress &);
+	virtual ~STUNClient();
 
 	virtual void Stop();
 
@@ -719,7 +714,7 @@ bool STUNClient::CreateSocketPair(UDPSocket * & rtp, UDPSocket * & rtcp, const P
 class GRQRequester : public RasRequester {
 public:
 	GRQRequester(const PString & gkid, H225_EndpointType & type);
-	~GRQRequester();
+	virtual ~GRQRequester();
 
 	// override from class RasRequester
 	virtual bool SendRequest(const Address &, WORD, int = 2);
