@@ -4,16 +4,11 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <ptlib/sockets.h>
 #include <ptclib/telnet.h>
@@ -99,6 +94,8 @@ public:
 		/// unique session ID (instance number) for this client
 		int instanceNo
 		);
+		
+	virtual ~StatusClient() {}
 
 	bool ReadCommand(
 		/// command that has been read (if ReadCommand succeeded)
@@ -233,7 +230,7 @@ private:
 	// filter vector
 	std::vector<PString>& regexFilters,
 	// Regex to be matched against messages
-	PString& regex
+	const PString& regex
 	);
 
     /** Remove regular expression filter located
@@ -1479,7 +1476,7 @@ void StatusClient::AddFilter(
     // vector of filters
     std::vector<PString>& regexFilters,
     // Regular expression
-    PString& regex
+    const PString& regex
     )
 {
     regexFilters.push_back(regex);
@@ -1492,7 +1489,7 @@ void StatusClient::RemoveFilter(
     unsigned int index
     )
 {
-    if (index < 0 || index >= regexFilters.size()) {
+    if (index >= regexFilters.size()) {
 		PString msg("Index mismatch.\r\n");
 		WriteData(msg, msg.GetLength());
 		return;
