@@ -5,13 +5,13 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKSTATUS_H
-#define GKSTATUS_H "@(#) $Id: GkStatus.h,v 1.29 2008/05/08 08:22:40 zvision Exp $"
+#define GKSTATUS_H "@(#) $Id: GkStatus.h,v 1.32 2009/05/15 07:33:14 willamowius Exp $"
 
 #include <map>
 #include "yasocket.h"
@@ -95,10 +95,10 @@ public:
 
 	enum StatusInterfaceCommands {
 		e_PrintAllRegistrations,
-		e_PrintAllRegistrationsVerbose,/// extra line per reg starting with '#'. yeah #.
+		e_PrintAllRegistrationsVerbose,/// extra line per reg starting with '#'.
 		e_PrintAllCached,
 		e_PrintCurrentCalls,
-		e_PrintCurrentCallsVerbose,    /// extra line per call starting with '#'. yeah #.
+		e_PrintCurrentCallsVerbose,    /// extra line per call starting with '#'.
 		e_Find,                        /// find an endpoint
 		e_FindVerbose,
 		e_DisconnectIp,                /// disconnect a call by endpoint IP number
@@ -187,6 +187,8 @@ public:
 		/// port number the socket is to be bound to
 		WORD port
 		);
+		
+	virtual ~StatusListener() {}
 
 	/** Create a new StatusClient socket that will be used
 		to accept a next incoming connection.
