@@ -1,12 +1,12 @@
 //////////////////////////////////////////////////////////////////
 //
-// New Neighboring System for GNU Gatekeeper
+// Neighboring System for GNU Gatekeeper
 //
 // Copyright (c) Citron Network Inc. 2002-2003
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -14,14 +14,6 @@
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-  #pragma warning(disable:4786) // warning about too long debug symbol off
-  #pragma warning(disable:4284)
-#endif
-#if defined(_WIN32) && (_MSC_VER > 1300)
-  #pragma warning(disable:4244) // warning about possible loss of data
-#endif
-
 #include <ptlib.h>
 #include <ptclib/pdns.h>
 #include <ptclib/enum.h>
@@ -40,7 +32,7 @@
 #include "config.h"
 
 #ifdef hasH460
-  #include <h460/h4601.h>
+	#include <h460/h4601.h>
 #endif
 
 using std::multimap;
@@ -57,6 +49,62 @@ namespace Neighbors {
 const char *NeighborSection = "RasSrv::Neighbors";
 const char *LRQFeaturesSection = "RasSrv::LRQFeatures";
 
+static const char OID_MD5[] = "1.2.840.113549.2.5";
+
+static PWCharArray GetUCS2plusNULL(const PString & str)
+{
+	PWCharArray ucs2 = str.AsUCS2();
+	PINDEX len = ucs2.GetSize();
+	if (len > 0 && ucs2[len-1] != 0)
+	  ucs2.SetSize(len+1);
+	return ucs2;
+}
+
+// helper function to calculate GKPwdHash (could migrate into H323Plus)
+void SetCryptoGkTokens(H225_ArrayOf_CryptoH323Token & cryptoTokens, const PString & id, const PString & password)
+{
+	// TODO: at least Tandberg seems to calculate the GKPwdHash differently
+	cryptoTokens.RemoveAll();
+	// Cisco compatible hash calculation
+	H235_ClearToken clearToken;
+
+	// fill the PwdCertToken to calculate the hash
+	clearToken.m_tokenOID = "0.0";
+
+	clearToken.IncludeOptionalField(H235_ClearToken::e_generalID);
+	clearToken.m_generalID = GetUCS2plusNULL(id);
+
+	clearToken.IncludeOptionalField(H235_ClearToken::e_password);
+	clearToken.m_password = GetUCS2plusNULL(password);
+
+	clearToken.IncludeOptionalField(H235_ClearToken::e_timeStamp);
+	clearToken.m_timeStamp = (int)time(NULL);
+
+	// Encode it into PER
+	PPER_Stream strm;
+	clearToken.Encode(strm);
+	strm.CompleteEncoding();
+
+	// Generate an MD5 of the clear tokens PER encoding.
+	PMessageDigest5 stomach;
+	stomach.Process(strm.GetPointer(), strm.GetSize());
+	PMessageDigest5::Code digest;
+	stomach.Complete(digest);
+
+	// Create the H.225 crypto token
+	H225_CryptoH323Token * finalCryptoToken = new H225_CryptoH323Token;
+	finalCryptoToken->SetTag(H225_CryptoH323Token::e_cryptoGKPwdHash);
+	H225_CryptoH323Token_cryptoGKPwdHash & cryptoGKPwdHash = *finalCryptoToken;
+
+	// Set the token data that actually goes over the wire
+	cryptoGKPwdHash.m_gatekeeperId = Toolkit::GKName();
+	cryptoGKPwdHash.m_timeStamp = clearToken.m_timeStamp;
+	cryptoGKPwdHash.m_token.m_algorithmOID = OID_MD5;
+	cryptoGKPwdHash.m_token.m_hash.SetData(sizeof(digest)*8, (const BYTE *)&digest);
+	
+	if (finalCryptoToken != NULL)
+		cryptoTokens.Append(finalCryptoToken);
+}
 
 class OldGK : public Neighbor {
 	// override from class Neighbor
@@ -176,10 +224,14 @@ PrefixInfo LRQForwarder::operator()(Neighbor *nb, WORD /*seqnum*/) const
 Neighbor::Neighbor()
 {
 	m_rasSrv = RasServer::Instance();
+	m_keepAliveTimer = GkTimerManager::INVALID_HANDLE;
+	m_keepAliveTimerInterval = 0;
 }
 
 Neighbor::~Neighbor()
 {
+	if (m_keepAliveTimer != GkTimerManager::INVALID_HANDLE)
+		Toolkit::Instance()->GetTimerManager()->UnregisterTimer(m_keepAliveTimer);
 	PTRACE(1, "NB\tDelete neighbor " << m_id);
 }
 
@@ -240,6 +292,8 @@ bool Neighbor::SetProfile(const PString & id, const PString & type)
 	m_name = config->GetString(section, "Host", "");
 	m_dynamic = Toolkit::AsBool(config->GetString(section, "Dynamic", "0"));
 	m_externalGK = false;
+	m_password = Toolkit::Instance()->ReadPassword(section, "Password");	// checking incomming password in LRQ (not implemented, yet)
+	m_sendPassword = Toolkit::Instance()->ReadPassword(section, "SendPassword", "");	// password to send to neighbor
 
 	if (!m_dynamic && !GetTransportAddress(m_name, GK_DEF_UNICAST_RAS_PORT, m_ip, m_port))
 		return false;
@@ -254,6 +308,13 @@ bool Neighbor::SetProfile(const PString & id, const PString & type)
 	}
 	PString aprefix(config->GetString(section, "AcceptPrefixes", "*"));
 	m_acceptPrefixes = PStringArray(aprefix.Tokenise(",", false));
+	if (m_keepAliveTimer != GkTimerManager::INVALID_HANDLE)
+		Toolkit::Instance()->GetTimerManager()->UnregisterTimer(m_keepAliveTimer);
+#ifdef HAS_H46018
+	if (Toolkit::AsBool(config->GetString(section, "UseH46018", "0"))) {
+		SetH46018GkKeepAliveInterval(29);	// start with every 29 seconds
+	}
+#endif
 
 	SetForwardedInfo(section);
 
@@ -266,9 +327,50 @@ bool Neighbor::SetProfile(const PString & id, const PString & type)
 	return true;
 }
 
+void Neighbor::SendH46018GkKeepAlive(GkTimer* timer)
+{
+#ifdef HAS_H46018
+	// send SCI to open the pinhole
+	H225_RasMessage sci_ras;
+	sci_ras.SetTag(H225_RasMessage::e_serviceControlIndication);
+	H225_ServiceControlIndication & sci = sci_ras;
+	sci.m_requestSeqNum = m_rasSrv->GetRequestSeqNum();
+	// Tandberg GK adds open here, the standard doesn't mention this
+	H225_ServiceControlSession controlOpen;
+	controlOpen.m_sessionId = 0;
+	controlOpen.m_reason = H225_ServiceControlSession_reason::e_open;
+	sci.m_serviceControl.SetSize(1);
+	sci.m_serviceControl[0] = controlOpen;
+	H460_FeatureStd feat = H460_FeatureStd(18);
+	sci.IncludeOptionalField(H225_ServiceControlIndication::e_featureSet);
+	sci.m_featureSet.IncludeOptionalField(H225_FeatureSet::e_supportedFeatures);
+	H225_ArrayOf_FeatureDescriptor & desc = sci.m_featureSet.m_supportedFeatures;
+	desc.SetSize(1);
+	desc[0] = feat;
+	if (!m_sendPassword.IsEmpty()) {
+		sci.IncludeOptionalField(H225_ServiceControlIndication::e_cryptoTokens);
+		sci.m_cryptoTokens.SetSize(1);
+		SetCryptoGkTokens(sci.m_cryptoTokens, Toolkit::GKName(), m_sendPassword);
+	}
+	m_rasSrv->SendRas(sci_ras, GetIP(), m_port);
+#endif
+}
+
+void Neighbor::SetH46018GkKeepAliveInterval(int interval)
+{
+	if (m_keepAliveTimerInterval != interval) {
+		m_keepAliveTimerInterval = interval;
+		if (m_keepAliveTimer != GkTimerManager::INVALID_HANDLE)
+			Toolkit::Instance()->GetTimerManager()->UnregisterTimer(m_keepAliveTimer);
+		PTime now;
+		if (m_keepAliveTimerInterval > 0)
+			m_keepAliveTimer = Toolkit::Instance()->GetTimerManager()->RegisterTimer(
+				this, &Neighbor::SendH46018GkKeepAlive, now, m_keepAliveTimerInterval);	// do it now and every n seconds
+	}
+}
+
 bool Neighbor::SetProfile(const PString & name, const H323TransportAddress & addr)
 {
-
   addr.GetIpAndPort(m_ip,m_port);
   m_id = "SRVrec";
   m_name = name;
@@ -754,7 +856,7 @@ bool GlonetGK::BuildLRQ(H225_LocationRequest & lrq, WORD crv)
 class LRQRequester : public RasRequester {
 public:
 	LRQRequester(const LRQFunctor &);
-	~LRQRequester();
+	virtual ~LRQRequester();
 
 	bool Send(NeighborList::List &, Neighbor * = 0);
 	bool Send(Neighbor * nb);
@@ -1041,10 +1143,10 @@ H225_CryptoH323Token BuildAccessToken(const H225_TransportAddress & dest, const
 
 	H235_ClearToken & clearToken = cryptoHashedToken.m_hashedVals;
 	clearToken.IncludeOptionalField(H235_ClearToken::e_timeStamp);
-	int timeStamp = time(0);
+	time_t timeStamp = time(0);
 	clearToken.m_timeStamp = timeStamp;
 
-	DWORD key = addr ^ timeStamp ^ challenge;
+	DWORD key = (DWORD)(addr ^ timeStamp ^ challenge);
 	PTEACypher::Key cryptokey;
 	memset(&cryptokey, challenge, sizeof(PTEACypher::Key));
 	memcpy(&cryptokey, &key, sizeof(DWORD));
@@ -1073,14 +1175,14 @@ bool DecodeAccessToken(const H225_CryptoH323Token & token, const PIPSocket::Addr
 	const H235_ClearToken & clearToken = cryptoHashedToken.m_hashedVals;
 	if (!clearToken.HasOptionalField(H235_ClearToken::e_timeStamp))
 		return false;
-	int now = time(0), timeStamp = clearToken.m_timeStamp.GetValue();
+	time_t now = time(0), timeStamp = clearToken.m_timeStamp.GetValue();
 	if (timeStamp > now || (now - timeStamp) > 30)
 		return false;
 
 	const PASN_BitString & bitstring = cryptoHashedToken.m_token.m_hash;
 	PString hashed((const char *)bitstring.GetDataPointer(), bitstring.GetSize() / 8);
 
-	DWORD key = addr ^ timeStamp ^ challenge;
+	DWORD key = (DWORD)(addr ^ timeStamp ^ challenge);
 	PTEACypher::Key cryptokey;
 	memset(&cryptokey, challenge, sizeof(PTEACypher::Key));
 	memcpy(&cryptokey, &key, sizeof(DWORD));
@@ -1102,6 +1204,7 @@ using namespace Neighbors;
 class NeighborPolicy : public Policy {
 public:
 	NeighborPolicy();
+	virtual ~NeighborPolicy() {}
 
 private:
 	// override from class Policy
