@@ -6,7 +6,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -15,11 +15,12 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef NEIGHBOR_H
-#define NEIGHBOR_H "@(#) $Id: Neighbor.h,v 1.18 2007/03/10 12:14:10 shorne Exp $"
+#define NEIGHBOR_H "@(#) $Id: Neighbor.h,v 1.23 2009/05/21 08:38:10 willamowius Exp $"
 
 #include <list>
 #include <map>
 #include "Routing.h"
+#include "gktimer.h"
 
 
 class H225_RasMessage;
@@ -82,6 +83,10 @@ public:
     // Sent profile based on SRV Record
 	virtual bool SetProfile(const PString &, const H323TransportAddress &);
 
+	// send a H.460.18 keepAlive (triggered by a timer)
+	void SendH46018GkKeepAlive(GkTimer* timer);
+	void SetH46018GkKeepAliveInterval(int interval);
+
 	// get PrefixInfo for a given aliases
 	// if an alias is matched, set dest to the alias
 	virtual PrefixInfo GetPrefixInfo(const H225_ArrayOf_AliasAddress &, H225_ArrayOf_AliasAddress & dest);
@@ -117,6 +122,9 @@ protected:
 	Prefixes m_sendPrefixes;
 	PStringArray m_acceptPrefixes;
 	bool m_externalGK;
+	PString m_sendPassword;	// password to send to neighbor
+	int m_keepAliveTimerInterval;
+	GkTimerManager::GkTimerHandle m_keepAliveTimer;
 };
 
 class NeighborList {
@@ -124,7 +132,7 @@ public:
 	typedef std::list<Neighbor *> List;
 
 	NeighborList();
-	~NeighborList();
+	virtual ~NeighborList();
 
 	void OnReload();
 
