@@ -8,7 +8,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -17,7 +17,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef RASSRV_H
-#define RASSRV_H "@(#) $Id: RasSrv.h,v 1.48 2008/08/27 12:37:54 willamowius Exp $"
+#define RASSRV_H "@(#) $Id: RasSrv.h,v 1.51 2009/02/19 14:51:33 willamowius Exp $"
 
 #include <vector>
 #include <list>
@@ -68,7 +68,7 @@ public:
 	typedef PIPSocket::Address Address;
 
 	RasServer();
-	~RasServer();
+	virtual ~RasServer();
 
 	// override from class SocketsReader
 	virtual void Stop();
@@ -204,29 +204,29 @@ public:
 	template<class RAS> bool HasAssignedGK(const PString & alias,const PIPSocket::Address & ip, RAS & ras)
 	{
 
-        H225_ArrayOf_AlternateGK * assignedGK = new H225_ArrayOf_AlternateGK;
-		assignedGK->SetSize(0);
+        H225_ArrayOf_AlternateGK assignedGK;
+		assignedGK.SetSize(0);
 
 		// Put query in here....
 		// Queries a DB for gatekeeper registrations with the first being
 		// the assigned gatekeeper. The alternates are then in preference order
 		// Note: If an assigned gatekeeper is found then the registration is not
 		// handled by this gatekeeper but by the assigned gatekeeper.
-		if (!Toolkit::Instance()->AssignedGKs().GetAssignedGK(alias,ip,*assignedGK))
+		if (!Toolkit::Instance()->AssignedGKs().GetAssignedGK(alias, ip, assignedGK))
 			return false;
 
-		if (assignedGK->GetSize() == 0)
+		if (assignedGK.GetSize() == 0)
 			return false;
 
         ras.IncludeOptionalField(RAS::e_assignedGatekeeper);
-		ras.m_assignedGatekeeper = (*assignedGK)[0];
+		ras.m_assignedGatekeeper = assignedGK[0];
 
-		if (assignedGK->GetSize() > 1) {
-			for (PINDEX i=1; i< assignedGK->GetSize(); i++) {
+		if (assignedGK.GetSize() > 1) {
+			for (PINDEX i=1; i< assignedGK.GetSize(); i++) {
 			   ras.m_alternateGatekeeper.SetSize(i);
-			   ras.m_alternateGatekeeper[i-1] = (*assignedGK)[i];
+			   ras.m_alternateGatekeeper[i-1] = assignedGK[i];
 			}
-		  ras.IncludeOptionalField(RAS::e_alternateGatekeeper);
+			ras.IncludeOptionalField(RAS::e_alternateGatekeeper);
 		}
 
 		return true;
