@@ -4,13 +4,13 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 #ifndef RASTBL_H
-#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.147 2008/11/16 12:54:16 willamowius Exp $"
+#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.155 2009/06/02 14:23:31 willamowius Exp $"
 
 #include <list>
 #include <map>
@@ -23,11 +23,6 @@
 #include "h323util.h"
 
 
-#if (_MSC_VER >= 1200)
-#pragma warning( disable : 4786 ) // warning about too long debug symbol off
-#pragma warning( disable : 4800 )
-#endif
-
 namespace Routing {
 	struct Route;
 }
@@ -119,19 +114,6 @@ public:
 		const H225_ArrayOf_AliasAddress* aliases
 		) const;
 
-	/** Find if one of the given aliases matches any alias for this endpoint
-		and return an index for the matching alias.
-
-		@return
-		true if the match has been found, false otherwise.
-	*/
-	virtual bool MatchAlias(
-		/// aliases to be matched (one of them)
-		const H225_ArrayOf_AliasAddress& aliases,
-		/// filled with an index into aliases for the matching alias (if found)
-		int& matchedalias
-		) const;
-
 	virtual void LoadAliases(
 		/// aliases to be matched (one of them)
 	    const H225_ArrayOf_AliasAddress& aliases,
@@ -178,9 +160,9 @@ public:
 	void SetNATProxy(PBoolean support) {m_natproxy = support; }
 	void SetInternal(PBoolean internal) { m_internal = internal; }
 
-	void SetPriority(int priority) { m_registrationPriority = priority; };
-	void SetPreemption(bool support) { m_registrationPreemption = support; };
-	void SetAssignedGatekeeper(const H225_AlternateGK & gk) { m_assignedGatekeeper = gk; };
+	void SetPriority(int priority) { m_registrationPriority = priority; }
+	void SetPreemption(bool support) { m_registrationPreemption = support; }
+	void SetAssignedGatekeeper(const H225_AlternateGK & gk) { m_assignedGatekeeper = gk; }
 	bool SetAssignedAliases(H225_ArrayOf_AliasAddress & assigned);
 
 
@@ -268,6 +250,10 @@ public:
 	unsigned TranslateReceivedCause(unsigned cause) const;
 	unsigned TranslateSentCause(unsigned cause) const;
 
+	bool IsH46018Disabled() const { return m_h46018disabled; }
+	void SetUsesH46018(bool uses) { m_usesH46018 = uses; m_nat = uses; }
+	bool UsesH46018() const { return m_usesH46018; }
+
 	// smart pointer for EndpointRec
 	typedef SmartPtr<EndpointRec> Ptr;
 
@@ -342,11 +328,12 @@ protected:
 
 	EPNatTypes m_epnattype;
 	bool m_natsupport, m_natproxy, m_internal, m_remote;
+	bool m_h46018disabled;
+	bool m_usesH46018;
 
 #ifdef hasPresence
 	H323Contact * m_contact;
 #endif
-
 };
 
 typedef EndpointRec::Ptr endptr;
@@ -597,8 +584,7 @@ public:
 		none = 0,
 		callingParty = 1,
 		calledParty = 2,
-		both = 3,
-		citronNAT = 4  // caller with Citron NAT Technology?
+		both = 3
 	};
 
 	PINDEX GetCallNumber() const { return m_CallNumber; }
@@ -715,6 +701,7 @@ public:
 	*/
 	bool IsConnected() const { return (m_connectTime != 0); }
 
+	void SetH245Routed(PBoolean routed) { m_h245Routed = routed; }
 	bool IsH245Routed() const { return m_h245Routed; }
 	bool IsToParent() const { return m_toParent; }
 	bool IsForwarded() const { return m_forwarded; }
@@ -759,6 +746,10 @@ public:
 		long seconds /// duration limit to be set
 		);
 
+	/** Set list of codecs to disable for this call */
+	void SetDisabledCodecs(const PString & codecs);
+	PString GetDisabledCodecs() const { return m_disabledcodecs; }
+
 	/** @return
 		Timestamp (number of seconds since 1st January 1970)
 		for the Setup message associated with this call. 0 if Setup
@@ -844,22 +835,22 @@ public:
 		Call duration in seconds. 0 for unconnected calls. Actual
 		duration for calls in progress.
 	*/
-	long GetDuration() const;
+	time_t GetDuration() const;
 
 	/** @return
 		Call total time in seconds. 0 for calls without disconnect.
 	*/
-	long GetTotalCallDuration() const;
+	time_t GetTotalCallDuration() const;
 
 	/** @return
 		Call Post Dial Delay in seconds.
 	*/
-	long GetPostDialDelay() const;
+	time_t GetPostDialDelay() const;
 
 	/** @return
 		Call ring time in seconds. 0 for calls without Alerting.
 	*/
-	long GetRingTime() const;
+	time_t GetRingTime() const;
 
 	/** @return
 		A string that identifies uniquelly this call for accounting
@@ -885,7 +876,7 @@ public:
 
 	/** Set the unregistered calling party signalling channel as NATed.
 	*/
-	void SetSrcNATed(PIPSocket::Address & natip);
+	void SetSrcNATed(const PIPSocket::Address & natip);
 
 	/** Set a new address for the called party signalling channel.
 	*/
@@ -972,7 +963,7 @@ public:
 	/** @return
         Call party to be charged for the call.
 	*/
-	PString GetCallLinkage()const { return m_callLinkage; };
+	PString GetCallLinkage()const { return m_callLinkage; }
 
 	/// Set calling party's number
 	void SetCalledStationId(
@@ -1036,9 +1027,14 @@ public:
 	void SetRADIUSClass(void * bytes, PINDEX len);
 	PBYTEArray GetRADIUSClass() const;
 	
-	bool IsProceedingSent() const { return m_proceedingSent; };
+	bool IsProceedingSent() const { return m_proceedingSent; }
 	// TODO: JW also set when sent via status port
-	void SetProceedingSent(bool val) { m_proceedingSent = val; };
+	void SetProceedingSent(bool val) { m_proceedingSent = val; }
+	
+#ifdef HAS_H46018
+	void StoreSetup(SignalingMsg * msg);
+	PBYTEArray RetrieveSetup();
+#endif
 
 private:
 	void SendDRQ();
@@ -1079,9 +1075,12 @@ private:
 	PString m_inbound_rewrite_id;
 	// rewrite id for outbound leg of call
 	PString m_outbound_rewrite_id;
+	
+	/// list of disabled codes
+	PString m_disabledcodecs;
 
 	/// current timeout (or duration limit) for the call
-	long m_timeout;
+	time_t m_timeout;
 	/// timestamp for call timeout measuring
 	time_t m_timer;
 	/// timestamp (seconds since 1st January, 1970) for the call creation
@@ -1099,7 +1098,7 @@ private:
 	/// timestamp for the most recent accounting update event logged for this call
 	time_t m_acctUpdateTime;
 	/// duration limit (seconds) for this call, 0 means no limit
-	long m_durationLimit;
+	time_t m_durationLimit;
 	/// Q.931 release complete cause code
 	unsigned m_disconnectCause;
 	/// Q.931 release complete cause code after translation
@@ -1162,6 +1161,10 @@ private:
 	PIPSocket::Address m_mediaOriginatingIp;
 	PBYTEArray m_radiusClass;
 	bool m_proceedingSent;
+#ifdef HAS_H46018
+	/// processed Setup data ready to be sent to the callee (for H.460.18)
+	PBYTEArray m_processedSetup;
+#endif
 };
 
 typedef CallRec::Ptr callptr;
@@ -1325,6 +1328,10 @@ inline H225_EndpointIdentifier EndpointRec::GetEndpointIdentifier() const
   
 inline int EndpointRec::GetTimeToLive() const
 {
+	if (UsesH46018()) {
+		// force timeToLive to 5 - 30 sec, 29 sec if not set
+		return m_timeToLive == 0 ? 29 : max(5, min(30, m_timeToLive));
+	}
 	return m_timeToLive;
 }
 
@@ -1359,6 +1366,9 @@ inline void EndpointRec::SetEndpointInfo(const PString & vendor, const PString &
 {
 	PWaitAndSignal lock(m_usedLock);
 
+	if (m_endpointVendor)
+		delete m_endpointVendor;
+
 	m_endpointVendor = new H225_VendorIdentifier();
 
 	m_endpointVendor->IncludeOptionalField(H225_VendorIdentifier::e_productId);
@@ -1606,12 +1616,12 @@ class PreliminaryCall
 {
 public:
 	PreliminaryCall(CallSignalSocket * callerSocket, H225_CallIdentifier id, unsigned ref)
-		: m_socket(callerSocket), m_callid(id), m_callref(ref) { };
-	~PreliminaryCall() { };
+		: m_socket(callerSocket), m_callid(id), m_callref(ref) { }
+	~PreliminaryCall() { }
 
-	CallSignalSocket * GetCallSignalSocketCalling() const { return m_socket; };
-	H225_CallIdentifier GetCallIdentifier() const { return m_callid; };
-	unsigned GetCallRef() const { return m_callref; };
+	CallSignalSocket * GetCallSignalSocketCalling() const { return m_socket; }
+	H225_CallIdentifier GetCallIdentifier() const { return m_callid; }
+	unsigned GetCallRef() const { return m_callref; }
 
 private:
 	CallSignalSocket * m_socket;
