@@ -6,7 +6,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -14,11 +14,6 @@
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)  
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <ptclib/enum.h>
 #include <h323pdu.h>
@@ -462,9 +457,7 @@ bool InternalPolicy::FindByAliases(
 	)
 {
 	list<Route> routes;
-	RegistrationTable::Instance()->FindEndpoint(
-		aliases, roundRobin, true, routes
-		);
+	RegistrationTable::Instance()->FindEndpoint(aliases, roundRobin, true, routes);
 	list<Route>::iterator i = routes.begin();
 	while (i != routes.end()) {
 		i->m_policy = m_name;
@@ -496,9 +489,8 @@ bool InternalPolicy::FindByAliases(
 	H225_ArrayOf_AliasAddress & aliases
 	)
 {
-	// do not apply round robin selection for Location ReQuests
 	list<Route> routes;
-	if (RegistrationTable::Instance()->FindEndpoint(aliases, false, true, routes))
+	if (RegistrationTable::Instance()->FindEndpoint(aliases, roundRobin, true, routes))
 		request.SetRejectReason(H225_ReleaseCompleteReason::e_gatewayResources);
 		
 	list<Route>::iterator i = routes.begin();
@@ -514,9 +506,8 @@ bool InternalPolicy::FindByAliases(
 	H225_ArrayOf_AliasAddress & aliases
 	)
 {
-	// do not apply round robin selection for Location ReQuests
 	list<Route> routes;
-	if (RegistrationTable::Instance()->FindEndpoint(aliases, false, true, routes))
+	if (RegistrationTable::Instance()->FindEndpoint(aliases, roundRobin, true, routes))
 		request.SetRejectReason(H225_AdmissionRejectReason::e_resourceUnavailable);
 		
 	list<Route>::iterator i = routes.begin();
@@ -811,7 +802,7 @@ bool VirtualQueue::RouteToAlias(
 	// signal the command to each pending request
 	bool foundrequest = false;
 	RouteRequests::iterator i = m_pendingRequests.begin();
-	while (i != m_pendingRequests.end()) {
+	while (!foundrequest && (i != m_pendingRequests.end())) {
 		RouteRequest *r = *i;
 		bool match = ((r->m_callingEpId == callingEpId) && (r->m_crv == crv));
 		if (!r->m_callID.IsEmpty() && !callID.IsEmpty()) {
@@ -1339,19 +1330,19 @@ bool ENUMPolicy::FindByAliases(LocationRequest & /* request */, H225_ArrayOf_Ali
 
 class DestinationRoutes {
 public:
-	DestinationRoutes() { m_endChain = false; m_reject = false; m_aliasesChanged = false;};
-	~DestinationRoutes() { };
+	DestinationRoutes() { m_endChain = false; m_reject = false; m_aliasesChanged = false;}
+	~DestinationRoutes() { }
 	
-	bool EndPolicyChain() const { return m_endChain; };
-	bool RejectCall() const { return m_reject; };
-	void SetRejectCall(bool reject) { m_reject = reject; m_endChain = true; };
-	unsigned int GetRejectReason() const { return m_rejectReason; };
-	void SetRejectReason(unsigned int reason) { m_rejectReason = reason; };
-	bool ChangeAliases() const { return m_aliasesChanged; };
-	H225_ArrayOf_AliasAddress GetNewAliases() const { return m_newAliases; };
-	void SetNewAliases(const H225_ArrayOf_AliasAddress & aliases) { m_newAliases = aliases; m_aliasesChanged = true; };
+	bool EndPolicyChain() const { return m_endChain; }
+	bool RejectCall() const { return m_reject; }
+	void SetRejectCall(bool reject) { m_reject = reject; m_endChain = true; }
+	unsigned int GetRejectReason() const { return m_rejectReason; }
+	void SetRejectReason(unsigned int reason) { m_rejectReason = reason; }
+	bool ChangeAliases() const { return m_aliasesChanged; }
+	H225_ArrayOf_AliasAddress GetNewAliases() const { return m_newAliases; }
+	void SetNewAliases(const H225_ArrayOf_AliasAddress & aliases) { m_newAliases = aliases; m_aliasesChanged = true; }
 	
-	void AddRoute(const Route & route) { m_routes.push_back(route); m_endChain = true; };
+	void AddRoute(const Route & route) { m_routes.push_back(route); m_endChain = true; }
 	
 	std::list<Route> m_routes;
 
@@ -1370,7 +1361,7 @@ public:
 	virtual ~SqlPolicy();
 
 protected:
-	virtual bool IsActive() const { return m_active; };
+	virtual bool IsActive() const { return m_active; }
 
 	virtual bool OnRequest(AdmissionRequest &);
 	virtual bool OnRequest(LocationRequest &);
@@ -1382,6 +1373,7 @@ protected:
 		const PString & calledAlias,
 		const PString & calledIP,
 		const PString & caller,
+		const PString & callingStationId,
 		const PString & callid,
 		const PString & messageType,
 		/* out: */
@@ -1392,7 +1384,7 @@ private:
 	bool m_active;
 	// connection to the SQL database
 	GkSQLConnection* m_sqlConn;
-	// parametrized query string for the auth condition string retrieval
+	// parametrized query string for the routing query
 	PString m_query;
 	// query timeout
 	long m_timeout;
@@ -1465,11 +1457,12 @@ bool SqlPolicy::OnRequest(AdmissionRequest & request)
 			calledAlias = AsString((*aliases)[0], FALSE);
 		PString calledIP = "";	/* not available for ARQs */
 		PString caller = AsString(arq.m_srcInfo, FALSE);
+		PString callingStationId = request.GetCallingStationId();
 		PString callid = AsString(arq.m_callIdentifier.m_guid);
 		PString messageType = "ARQ";
 		DestinationRoutes destination;
 
-		DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callid, messageType,
+		DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callingStationId, callid, messageType,
 						/* out: */ destination);
 
 		if (destination.RejectCall()) {
@@ -1515,11 +1508,14 @@ bool SqlPolicy::OnRequest(LocationRequest & request)
 	PString caller = "";
 	if (lrq.HasOptionalField(H225_LocationRequest::e_sourceInfo) && (lrq.m_sourceInfo.GetSize() > 0))
 		caller = AsString(lrq.m_sourceInfo[0], FALSE);
+	PString callingStationId = request.GetCallingStationId();
+	if (callingStationId.IsEmpty())
+		callingStationId = caller;
 	PString callid = "";	/* not available for LRQs */
 	PString messageType = "LRQ";
 	DestinationRoutes destination;
 
-	DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callid, messageType,
+	DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callingStationId,callid, messageType,
 					/* out: */ destination);
 
 	if (destination.RejectCall()) {
@@ -1561,11 +1557,12 @@ bool SqlPolicy::OnRequest(SetupRequest & request)
 	request.GetWrapper()->GetLocalAddr(localAddr, localPort);
 	PString calledIP = localAddr;
 	PString caller = AsString(setup.m_sourceAddress, FALSE);
+	PString callingStationId = request.GetCallingStationId();
 	PString callid = AsString(setup.m_callIdentifier.m_guid);
 	PString messageType = "Setup";
 	DestinationRoutes destination;
 
-	DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callid, messageType,
+	DatabaseLookup(	/* in */ source, calledAlias, calledIP, caller, callingStationId, callid, messageType,
 					/* out: */ destination);
 
 	if (destination.RejectCall()) {
@@ -1605,6 +1602,7 @@ void SqlPolicy::DatabaseLookup(
 		const PString & calledAlias,
 		const PString & calledIP,
 		const PString & caller,
+		const PString & callingStationId,
 		const PString & callid,
 		const PString & messageType,
 		/* out: */
@@ -1617,6 +1615,7 @@ void SqlPolicy::DatabaseLookup(
 	params["c"] = calledAlias;
 	params["p"] = calledIP;
 	params["r"] = caller;
+	params["Calling-Station-Id"] = callingStationId;
 	params["i"] = callid;
 	params["m"] = messageType;
 	GkSQLResult* result = m_sqlConn->ExecuteQuery(m_query, params, m_timeout);
