@@ -4,18 +4,13 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Jan Willamowius
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)  
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <h323pdu.h>
 #include "gk_const.h"
