@@ -4,19 +4,11 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-  #pragma warning(disable:4786) // warning about too long debug symbol off
-  #pragma warning(disable:4284)
-#endif
-#if defined(_WIN32) && (_MSC_VER > 1300)
-  #pragma warning(disable:4244) // warning about possible loss of data
-#endif
-
 #include <ptlib.h>
 #include <ptclib/pdns.h>
 #include <ptclib/cypher.h>
@@ -400,7 +392,7 @@ bool Toolkit::VirtualRouteTable::CreateTable()
 	return false;
 }
 
-bool Toolkit::VirtualRouteTable::IsMasquerade(PIPSocket::Address & addr)
+bool Toolkit::VirtualRouteTable::IsMasquerade(PIPSocket::Address & addr) const
 {
 	if (!ExtIP) {
 	  H323TransportAddress ex = H323TransportAddress(ExtIP);
@@ -696,12 +688,8 @@ void Toolkit::GWRewriteTool::PrintData() {
 }
 
 
-void Toolkit::GWRewriteTool::LoadConfig(PConfig *config) {
-
-	PINDEX gw_size, i, j, lines_size;
-	PString key, cfg_value;
-	PStringArray lines, tokenised_line;
-	GWRewriteEntry *gw_entry;
+void Toolkit::GWRewriteTool::LoadConfig(PConfig *config)
+{
 	std::map<PString,PString> in_strings, out_strings;
 	vector<std::pair<PString,PString> > sorted_in_strings, sorted_out_strings;
 	std::map<PString,PString>::reverse_iterator strings_iterator;
@@ -710,18 +698,18 @@ void Toolkit::GWRewriteTool::LoadConfig(PConfig *config) {
 	PStringToString cfgs(config->GetAllKeyValues(GWRewriteSection));
 
 	// Clear old config
-	for (i = 0; i < m_GWRewrite.GetSize(); ++i) {
+	for (PINDEX i = 0; i < m_GWRewrite.GetSize(); ++i) {
 		delete &(m_GWRewrite.GetDataAt(i));
 	}
 	m_GWRewrite.RemoveAll();
 
-	gw_size = cfgs.GetSize();
+	PINDEX gw_size = cfgs.GetSize();
 	if (gw_size > 0) {
-		for (i = 0; i < gw_size; ++i) {
+		for (PINDEX i = 0; i < gw_size; ++i) {
 
 			// Get the config keys
-			key = cfgs.GetKeyAt(i);
-			cfg_value = cfgs[key];
+			PString key = cfgs.GetKeyAt(i);
+			PString cfg_value = cfgs[key];
 
 			in_strings.clear();
 			out_strings.clear();
@@ -729,14 +717,14 @@ void Toolkit::GWRewriteTool::LoadConfig(PConfig *config) {
 			sorted_out_strings.clear();
 
 			// Split the config data into seperate lines
-			lines = cfg_value.Tokenise(PString(";"));
+			PStringArray lines = cfg_value.Tokenise(PString(";"));
 
-			lines_size = lines.GetSize();
+			PINDEX lines_size = lines.GetSize();
 
-			for (j = 0; j < lines_size; ++j) {
+			for (PINDEX j = 0; j < lines_size; ++j) {
 
 				// Split the config line into three strings, direction, from string, to string
-				tokenised_line = lines[j].Tokenise(PString("="));
+				PStringArray tokenised_line = lines[j].Tokenise(PString("="));
 
 				if (tokenised_line.GetSize() < 3) {
 					PTRACE(0, "GK\tSyntax error in the GWRewriteE164 rule - missing =, rule: " 
@@ -746,7 +734,6 @@ void Toolkit::GWRewriteTool::LoadConfig(PConfig *config) {
 				}
 
 				// Put into appropriate std::map
-
 				if (tokenised_line[0] == "in")
 					in_strings[tokenised_line[1]] = tokenised_line[2];
 				else if (tokenised_line[0] == "out")
@@ -768,14 +755,12 @@ void Toolkit::GWRewriteTool::LoadConfig(PConfig *config) {
 			}
 
 			// Create the entry
-			gw_entry = new GWRewriteEntry();
+			GWRewriteEntry * gw_entry = new GWRewriteEntry();
 			gw_entry->m_entry_data.first = sorted_in_strings;
 			gw_entry->m_entry_data.second = sorted_out_strings;
 
-
 			// Add to PDictionary hash table
-			m_GWRewrite.Insert(key,gw_entry);
-
+			m_GWRewrite.Insert(key, gw_entry);
 		}
 	}
 
@@ -790,7 +775,7 @@ Toolkit::Toolkit() : Singleton<Toolkit>("Toolkit"),
 	m_encKeyPaddingByte(-1), m_encryptAllPasswords(false),
 	m_cliRewrite(NULL)
 {
-	srand(time(0));
+	srand((unsigned int)time(0));
 }
 
 Toolkit::~Toolkit()
@@ -1296,10 +1281,12 @@ PConfig* Toolkit::ReloadConfig()
 {
 	// make a new symlink if needed
 	PrepareReloadConfig();
+
 	// read the toolkit config values
 
+	// read the gatekeeper name from the config file, because it might be uased as a key into the SQL config
 	m_GKName = Config()->GetString("Name", "OpenH323GK");
-	
+
 	m_encryptAllPasswords = Toolkit::AsBool(
 		Config()->GetString("EncryptAllPasswords", "0")
 		);
@@ -1307,9 +1294,15 @@ PConfig* Toolkit::ReloadConfig()
 		m_encKeyPaddingByte = Config()->GetInteger(paddingByteConfigKey, 0);
 	else
 		m_encKeyPaddingByte = m_encryptAllPasswords ? 0 : -1;
-		
+
 	ReloadSQLConfig();
 
+	// update the gatekeeper name, in case it was set in the SQL config
+	m_GKName = m_Config->GetString("Name", "OpenH323GK");
+#ifdef HAS_H46018
+	m_H46018Enabled	= m_Config->GetBoolean(RoutedSec, "EnableH46018", 0);
+#endif
+
 	// TODO/BUG: always call SetGKHome() on reload, even if we don't have a Home= setting
 	// otherwise we won't detect new IPs on the machine
 	PString GKHome(m_Config->GetString("Home", ""));
@@ -1329,7 +1322,7 @@ PConfig* Toolkit::ReloadConfig()
 	m_qosMonitor.LoadConfig(m_Config);
 #endif
 
-	m_timestampFormatStr = Config()->GetString("TimestampFormat", "Cisco");
+	m_timestampFormatStr = m_Config->GetString("TimestampFormat", "Cisco");
 
 	delete m_cliRewrite;
 	m_cliRewrite = new CLIRewrite;
@@ -1340,8 +1333,8 @@ PConfig* Toolkit::ReloadConfig()
 
 	LoadReasonMap(m_Config);
 
-	ParseTranslationMap(m_receivedCauseMap, Config()->GetString(RoutedSec, "TranslateReceivedQ931Cause", ""));
-	ParseTranslationMap(m_sentCauseMap, Config()->GetString(RoutedSec, "TranslateSentQ931Cause", ""));
+	ParseTranslationMap(m_receivedCauseMap, m_Config->GetString(RoutedSec, "TranslateReceivedQ931Cause", ""));
+	ParseTranslationMap(m_sentCauseMap, m_Config->GetString(RoutedSec, "TranslateSentQ931Cause", ""));
 	
 	return m_Config;
 }
@@ -2073,14 +2066,14 @@ bool Toolkit::QoSMonitor::PostRecord(const std::map<PString, PString>& params)
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
-bool Toolkit::RewriteE164(H225_AliasAddress &alias)
+bool Toolkit::RewriteE164(H225_AliasAddress & alias)
 {
 	if ((alias.GetTag() != H225_AliasAddress::e_dialedDigits) &&
          (alias.GetTag() != H225_AliasAddress::e_h323_ID) &&
 		 (alias.GetTag() != H225_AliasAddress::e_url_ID)) {
 		if (alias.GetTag() != H225_AliasAddress::e_partyNumber)
 			return false;
-		H225_PartyNumber &partyNumber = alias;
+		H225_PartyNumber & partyNumber = alias;
 		if (partyNumber.GetTag() != H225_PartyNumber::e_e164Number && partyNumber.GetTag() != H225_PartyNumber::e_privateNumber)
 			return false;
 	}
@@ -2092,13 +2085,15 @@ bool Toolkit::RewriteE164(H225_AliasAddress &alias)
 		if (alias.GetTag() == H225_AliasAddress::e_dialedDigits)
 			H323SetAliasAddress(E164, alias, alias.GetTag());
 		else {
-			H225_PartyNumber &partyNumber = alias;
-			if (partyNumber.GetTag() == H225_PartyNumber::e_e164Number) {
-				H225_PublicPartyNumber &number = partyNumber;
-				number.m_publicNumberDigits = E164;
-			} else if (partyNumber.GetTag() == H225_PartyNumber::e_privateNumber) {
-				H225_PrivatePartyNumber &number = partyNumber;
-				number.m_privateNumberDigits = E164;
+			if (alias.GetTag() == H225_AliasAddress::e_partyNumber) {
+				H225_PartyNumber & partyNumber = alias;
+				if (partyNumber.GetTag() == H225_PartyNumber::e_e164Number) {
+					H225_PublicPartyNumber &number = partyNumber;
+					number.m_publicNumberDigits = E164;
+				} else if (partyNumber.GetTag() == H225_PartyNumber::e_privateNumber) {
+					H225_PrivatePartyNumber &number = partyNumber;
+					number.m_privateNumberDigits = E164;
+				}
 			}
 		}
 	}
@@ -2161,7 +2156,7 @@ bool Toolkit::GWRewriteE164(PString gw, bool direction, H225_ArrayOf_AliasAddres
 	return changed;
 }
 
-bool Toolkit::isBehindNAT(PIPSocket::Address & externalIP) {
+bool Toolkit::isBehindNAT(PIPSocket::Address & externalIP) const {
 
    return (m_VirtualRouteTable.IsMasquerade(externalIP));
 }
