@@ -4,16 +4,17 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 #ifndef TOOLKIT_H
-#define TOOLKIT_H "@(#) $Id: Toolkit.h,v 1.59 2008/11/08 01:35:21 willamowius Exp $"
+#define TOOLKIT_H "@(#) $Id: Toolkit.h,v 1.64 2009/06/08 10:42:11 willamowius Exp $"
 
 #include <vector>
 #include <map>
+#include <ptlib.h>
 #include <ptlib/sockets.h>
 #include "singleton.h"
 #include "config.h"
@@ -112,16 +113,16 @@ class Toolkit : public Singleton<Toolkit>
 	public:
 		RouteTable() : rtable_begin(0), DynExtIP(false), ExtIP("") { /* initialize later */ }
 		virtual ~RouteTable() { ClearTable(); }
-		Address GetLocalAddress() const { return defAddr; };
+		Address GetLocalAddress() const { return defAddr; }
 		Address GetLocalAddress(const Address &) const;
 
 		void InitTable();
 		void ClearTable();
 		bool IsEmpty() const { return rtable_begin == 0; }
 
-		std::vector<NetworkAddress> GetInternalNetworks() { return m_internalnetworks; }
+		std::vector<NetworkAddress> GetInternalNetworks() const { return m_internalnetworks; }
 
-	    virtual bool IsMasquerade(PIPSocket::Address &) { return false; }
+	    virtual bool IsMasquerade(const PIPSocket::Address &) const { return false; }
 	protected:
 		class RouteEntry : public PIPSocket::RouteEntry {
 		public:
@@ -143,7 +144,7 @@ class Toolkit : public Singleton<Toolkit>
 	class VirtualRouteTable : public RouteTable {
 		// override from class  RouteTable
 	public:
-		virtual bool IsMasquerade(PIPSocket::Address &);
+		virtual bool IsMasquerade(PIPSocket::Address &) const;
 	protected:
 		virtual bool CreateTable();
 		
@@ -341,8 +342,11 @@ class Toolkit : public Singleton<Toolkit>
 	PString GetGKHome(std::vector<PIPSocket::Address> &) const;
 	void SetGKHome(const PStringArray &);
 
-	bool isBehindNAT(PIPSocket::Address &);
+	bool isBehindNAT(PIPSocket::Address &) const;
 	std::vector<NetworkAddress> GetInternalNetworks();
+#ifdef HAS_H46018
+	bool IsH46018Enabled() const { return m_H46018Enabled; }
+#endif
 
 	// accessors
 	/** Accessor and 'Factory' to the static Toolkit.
@@ -586,6 +590,10 @@ private:
 	/// global cause code translation
 	std::map<unsigned, unsigned> m_receivedCauseMap;
 	std::map<unsigned, unsigned> m_sentCauseMap;
+	// is H460.18 enabled ?
+#ifdef HAS_H46018
+	bool m_H46018Enabled;
+#endif
 };
 
 
