@@ -3,18 +3,15 @@
  *
  * Module for accoutning per IP/H.323 ID/CLI/prefix inbound call volume
  *
- * $Id: capctrl.cxx,v 1.14 2008/09/19 08:10:57 willamowius Exp $
+ * $Id: capctrl.cxx,v 1.18 2009/05/24 20:48:26 willamowius Exp $
  *
  * Copyright (c) 2006, Michal Zygmuntowicz
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  */
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4284)
-#endif
 
 #include <ptlib.h>
 #include <ptlib/ipsock.h>
@@ -35,14 +32,13 @@ struct IpRule_greater : public std::binary_function<CapacityControl::IpCallVolum
 
 	bool operator()(const CapacityControl::IpCallVolume &e1, const CapacityControl::IpCallVolume &e2) const 
 	{
-		int diff;
 		if (e1.first.IsAny()) {
 			if (!e2.first.IsAny())
 				return false;
 		} else {
 			if (e2.first.IsAny())
 				return true;
-			diff = e1.first.Compare(e2.first);
+			int diff = e1.first.Compare(e2.first);
 			if (diff != 0)
 				return diff > 0;
 		}
@@ -643,6 +639,7 @@ public:
 		/// Misc check events supported by this module
 		unsigned supportedMiscChecks = CapCtrlAuthMiscChecks
 		);
+	virtual ~CapCtrlAuth() {}
 	
 	/** Authenticate using data from Q.931 Setup message.
 	
