@@ -3,18 +3,15 @@
  *
  * Module for CLI/ANI manipulation.
  *
- * $Id: clirw.cxx,v 1.18 2008/05/20 18:13:51 willamowius Exp $
+ * $Id: clirw.cxx,v 1.21 2009/05/24 20:48:26 willamowius Exp $
  *
  * Copyright (c) 2005, Michal Zygmuntowicz
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  */
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4284)
-#endif
 
 #include <ptlib.h>
 #include <ptlib/ipsock.h>
@@ -119,14 +116,13 @@ struct SingleIpRule_greater : public std::binary_function<CLIRewrite::SingleIpRu
 
 	bool operator()(const CLIRewrite::SingleIpRule &e1, const CLIRewrite::SingleIpRule &e2) const 
 	{
-		int diff;
 		if (e1.first.IsAny()) {
 			if (!e2.first.IsAny())
 				return false;
 		} else {
 			if (e2.first.IsAny())
 				return true;
-			diff = e1.first.Compare(e2.first);
+			int diff = e1.first.Compare(e2.first);
 			if (diff != 0)
 				return diff > 0;
 		}
