@@ -7,11 +7,11 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  */
 #ifndef CLIRW_H
-#define CLIRW_H "#(@) $Id: clirw.h,v 1.5 2008/05/08 10:39:29 zvision Exp $"
+#define CLIRW_H "#(@) $Id: clirw.h,v 1.6 2009/02/09 13:25:59 willamowius Exp $"
 
 #include <string>
 #include <vector>
