@@ -1,20 +1,15 @@
 //////////////////////////////////////////////////////////////////
 //
-// gk.cxx for OpenH323 Gatekeeper - GNU Gatekeeper
+// gk.cxx for GNU Gatekeeper
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)  
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <ptlib/sockets.h>
 #ifndef _WIN32
@@ -249,7 +244,7 @@ bool Gatekeeper::SetUserAndGroup(const PString &username)
 	char buffer[MAX_PASSWORD_BUFSIZE];
 
 #if defined (P_LINUX) || defined (P_AIX) || defined(P_IRIX) || (__GNUC__>=3 && defined(P_SOLARIS)) || defined(P_RTEMS)
-	::getpwnam_r(username,&userdata,buffer,sizeof(buffer),&userptr);
+	::getpwnam_r(username, &userdata, buffer, sizeof(buffer), &userptr);
 #else
 	userptr = ::getpwnam_r(username, &userdata, buffer, sizeof(buffer));
 #endif
@@ -473,9 +468,8 @@ bool Gatekeeper::InitConfig(const PArgList &args)
 	if( (GkConfig()->GetInteger("Fortytwo")  != 42) &&
 		(GkConfig()->GetInteger("Fourtytwo") != 42)) { 
 		cerr << "WARNING: No config file found!\n"
-			 << "- Does the config file exist? The default (~/.pwlib_config/Gatekeeper.ini or gatekeeper.ini in current directory) or the one given with -c?\n"
-			 << "- Did you specify they the right 'Main' section with -s?\n" 
-			 << "- Is the line 'Fortytwo=42' present in this 'Main' section?"<<endl;
+			 << "- Use the -c switch to specify the config file.\n"
+			 << "- Make sure the line 'Fortytwo=42' is present in the '[Gatekeeper::Main]' section.\n" << endl;
 	}
 	
 	return CheckSectionName(GkConfig());
@@ -592,7 +586,7 @@ void Gatekeeper::Main()
 
 	EnableLogFileRotation();
 	
-	PString welcome("OpenH323 Gatekeeper - The GNU Gatekeeper with ID '" + Toolkit::GKName() + "' started\n" + Toolkit::GKVersion());
+	PString welcome("GNU Gatekeeper with ID '" + Toolkit::GKName() + "' started\n" + Toolkit::GKVersion());
 	cout << welcome << '\n';
 	PTRACE(1, welcome);
 
@@ -613,18 +607,24 @@ void Gatekeeper::Main()
 	// Copyright notice
 	cout <<
 		"This program is free software; you can redistribute it and/or\n"
-		"modify it under the terms of the GNU General Public License\n"
-		"as published by the Free Software Foundation; either version 2\n"
-		"of the License, or (at your option) any later version.\n"
+		"modify it under the terms of the GNU General Public License version 2.\n"
+		"We also explicitly grant the right to link this code\n"
+		"with the OpenH323/H323Plus and OpenSSL library.\n"
 	     << endl;
 
 #ifdef hasH460
 	// License notice
 	cout << "This program contains patent pending P2Pnat Media technology\n"
-            "under special royalty-free license to the GnuGk Project"
+            "under special royalty-free license to the GNU Gatekeeper Project.\n"
 		 << endl;
 #endif
 
+#ifdef HAS_H46018
+	cout << "This program contains H.460.18 and H.460.19 technology patented by Tandberg\n"
+			"licensed to the GNU Gatekeeper Project.\n"
+			<< endl;
+#endif
+
 	// read capacity from commandline
 	int GKcapacity;
 	if (args.HasOption('b'))
@@ -633,9 +633,9 @@ void Gatekeeper::Main()
 		GKcapacity = GkConfig()->GetInteger("TotalBandwidth", -1);
 	CallTable::Instance()->SetTotalBandwidth(GKcapacity);
 	if (GKcapacity < 0)
-		cout << "\nDisable Bandwidth Management" << endl;
+		PTRACE(2, "GK\tDisable Bandwidth Management");
 	else
-		cout << "\nAvailable Bandwidth " << GKcapacity << endl;
+		PTRACE(2, "GK\tAvailable Bandwidth " << GKcapacity);
 
 	// read timeToLive from command line
 	if (args.HasOption('l'))
