@@ -4,14 +4,14 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 
 #ifndef GK_CONST_H
-#define GK_CONST_H "@(#) $Id: gk_const.h,v 1.18 2008/04/25 02:51:56 shorne Exp $"
+#define GK_CONST_H "@(#) $Id: gk_const.h,v 1.20 2009/05/24 21:53:29 willamowius Exp $"
 
 /* all values can be set in the config file, section [Gatekeeper::<InstanceName>]
  * these are just the defaults
@@ -33,16 +33,6 @@
 
 extern const char *H225_ProtocolID;
 
-#ifdef _WIN32
-#ifndef _OpenH323_VERSION_H
-#ifndef H323PLUS_LIB
-#include <../../openh323/version.h> // get OpenH323 version
-#else
-#include <../../h323plus/version.h> // get h323plus version
-#endif
-#endif
-#endif
-
 ///////////////////////////////////////
 //OIDs
 #define GnuGkOID "1.3.6.1.4.1.27938"
