@@ -8,10 +8,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: gkacct.cxx,v $
+ * Revision 1.38  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.37  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.36  2008/07/10 08:21:20  willamowius
  * avoid gcc 4.3.x warnings
  *
@@ -136,10 +142,6 @@
  * Initial generic accounting support for GNU GK.
  *
  */
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
 
 #include <ptlib.h>
 #include <h225.h>
