@@ -4,19 +4,11 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-  #pragma warning(disable:4786) // warning about too long debug symbol off
-  #pragma warning(disable:4284)
-#endif
-#if defined(_WIN32) && (_MSC_VER > 1300)
-  #pragma warning(disable:4244) // warning about possible loss of data
-#endif
-
 #include <ptlib.h>
 #include <h235.h>
 #include <h323pdu.h>
@@ -1101,7 +1093,7 @@ bool CacheManager::Retrieve(
 	if (iter == m_cache.end())
 		return false;
 	if (m_ttl >= 0) {
-		std::map<PString, long>::const_iterator i = m_ctime.find(key);
+		std::map<PString, time_t>::const_iterator i = m_ctime.find(key);
 		if (i == m_ctime.end() || (time(NULL) - i->second) >= m_ttl)
 			return false; // cache expired
 	}
@@ -1138,6 +1130,7 @@ SimplePasswordAuth::SimplePasswordAuth(
 	m_encryptionKey = GetConfig()->GetInteger(name, "KeyFilled", 0);
 	m_checkID = Toolkit::AsBool(GetConfig()->GetString(name, "CheckID", "0"));
 	m_cache = new CacheManager(GetConfig()->GetInteger(name, "PasswordTimeout", -1));
+	m_disabledAlgorithms = GetConfig()->GetString(name, "DisableAlgorithm", "").Tokenise(",;", FALSE);
 
 #ifdef OpenH323Factory
 	PStringList authlist = Toolkit::Instance()->GetAuthenticatorList();
@@ -1145,36 +1138,48 @@ SimplePasswordAuth::SimplePasswordAuth(
     PFactory<H235Authenticator>::KeyList_T keyList = PFactory<H235Authenticator>::GetKeyList();
     PFactory<H235Authenticator>::KeyList_T::const_iterator r;
     for (r = keyList.begin(); r != keyList.end(); ++r) {
-      H235Authenticator * Auth = PFactory<H235Authenticator>::CreateInstance(*r);
-       if (authlist.GetSize() > 0) {
-		for (PINDEX i=0; i< authlist.GetSize(); i++) {
-			if (PString(Auth->GetName()) == authlist[i])
-               AppendH235Authenticator(Auth);
+		H235Authenticator * Auth = PFactory<H235Authenticator>::CreateInstance(*r);
+		// only use, if it's not disabled for this GnuGk authentication method
+		if (m_disabledAlgorithms.GetStringsIndex(Auth->GetName()) == P_MAX_INDEX) {
+			if (authlist.GetSize() > 0) {
+				// if a global list of autenticators is configures, use it only if its on the list
+				for (PINDEX i=0; i< authlist.GetSize(); i++) {
+					if (PString(Auth->GetName()) == authlist[i])
+						AppendH235Authenticator(Auth);
+				}
+			} else {
+				// without global authenticator list: use all
+				AppendH235Authenticator(Auth);
+			}
 		}
-	   } else
-	       AppendH235Authenticator(Auth);
 	}
 #else
 	H235Authenticator* authenticator;
 
-	authenticator = new H235AuthSimpleMD5;
-	authenticator->SetLocalId("dummy");
-	authenticator->SetRemoteId("dummy");
-	authenticator->SetPassword("dummy");
-	AppendH235Authenticator(authenticator);
-	authenticator = new H235AuthCAT;
-	authenticator->SetLocalId("dummy");
-	authenticator->SetRemoteId("dummy");
-	authenticator->SetPassword("dummy");
-	AppendH235Authenticator(authenticator);
+	if (m_disabledAlgorithms.GetStringsIndex("MD5") == P_MAX_INDEX) {
+		authenticator = new H235AuthSimpleMD5;
+		authenticator->SetLocalId("dummy");
+		authenticator->SetRemoteId("dummy");
+		authenticator->SetPassword("dummy");
+		AppendH235Authenticator(authenticator);
+	}
+	if (m_disabledAlgorithms.GetStringsIndex("CAT") == P_MAX_INDEX) {
+		authenticator = new H235AuthCAT;
+		authenticator->SetLocalId("dummy");
+		authenticator->SetRemoteId("dummy");
+		authenticator->SetPassword("dummy");
+		AppendH235Authenticator(authenticator);
+	}
 
-//#if P_SSL
-//	authenticator = new H235AuthProcedure1;
-//	authenticator->SetLocalId("dummy");
-//	authenticator->SetRemoteId("dummy");
-//	authenticator->SetPassword("dummy");
-//	AppendH235Authenticator(authenticator);
-//#endif
+#if P_SSL
+	if (m_disabledAlgorithms.GetStringsIndex("H.235.1") == P_MAX_INDEX) {
+		authenticator = new H235AuthProcedure1;
+		authenticator->SetLocalId("dummy");
+		authenticator->SetRemoteId("dummy");
+		authenticator->SetPassword("dummy");
+		AppendH235Authenticator(authenticator);
+	}
+#endif
 
 #endif
 
@@ -1514,7 +1519,7 @@ bool SimplePasswordAuth::ResolveUserName(
 		} 
 	}
 
-	for (PINDEX j = 0; j < cryptotokens.GetSize(); j++) {
+	for (PINDEX j = 0; j < tokens.GetSize(); j++) {
 		H235_ClearToken& token = tokens[j];
 		// CAT
 			if (token.HasOptionalField(H235_ClearToken::e_generalID)) {
