@@ -6,13 +6,13 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKAUTH_H
-#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.40 2008/05/08 08:22:40 zvision Exp $"
+#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.45 2009/05/24 21:53:29 willamowius Exp $"
 
 #include <map>
 #include <list>
@@ -85,7 +85,7 @@ struct ARQAuthData
 		const endptr& ep,
 		const callptr& call
 		);
-	~ARQAuthData();
+	virtual ~ARQAuthData();
 		
 	ARQAuthData& operator=(const ARQAuthData& obj);
 		
@@ -97,6 +97,8 @@ struct ARQAuthData
 	int m_rejectReason;
 	/// -1 if not set, max allowe call duration in seconds otherwise
 	long m_callDurationLimit;
+	/// disabled codecs
+	PString m_disabledcodecs;
 	/// endpoint that sent the request
 	endptr m_requestingEP;
 	/// call associated with the request (if any, only for answering ARQ)
@@ -139,7 +141,7 @@ struct SetupAuthData
 		/// is the Setup message from a registered endpoint
 		bool fromRegistered
 		);
-	~SetupAuthData();
+	virtual ~SetupAuthData();
 		
 	SetupAuthData& operator=(const SetupAuthData& obj);
 	
@@ -153,6 +155,8 @@ struct SetupAuthData
 	int m_rejectCause;
 	/// -1 if not set, max allowe call duration in seconds otherwise
 	long m_callDurationLimit;
+	/// disabled codecs
+	PString m_disabledcodecs;
 	/// call associated with the message (if any)
 	callptr m_call;
 	/// is the Setup message from a registered endpoint
@@ -503,7 +507,7 @@ private:
 	/// cached key-value pairs
 	std::map<PString, PString> m_cache;
 	/// timestamps for key-value pair expiration calculation
-	std::map<PString, long> m_ctime;
+	std::map<PString, time_t> m_ctime;
 	/// mutex for multiple read/mutual write access to the cache
 	mutable PReadWriteMutex m_rwmutex;
 };      
@@ -745,6 +749,8 @@ private:
 	bool m_checkID;
 	/// cache for username/password pairs
 	CacheManager* m_cache;
+	/// list of H.235 algorithms to disable
+	PStringArray m_disabledAlgorithms;
 };
 
 
@@ -887,7 +893,7 @@ class GkAuthenticatorList
 public:
 	/// creates an empty list - OnRealod builds the actual stack of authenticator
 	GkAuthenticatorList();
-	~GkAuthenticatorList();
+	virtual ~GkAuthenticatorList();
 
 	/// read the config file and build a new stack of authenticator modules
 	void OnReload();
