@@ -7,10 +7,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: gksql.h,v $
+ * Revision 1.17  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.16  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.15  2008/09/05 13:44:14  zvision
  * GetInfo implemented for SQL acct/auth modules
  *
@@ -58,7 +64,7 @@
  *
  */
 #ifndef GKSQL_H
-#define GKSQL_H "@(#) $Id: gksql.h,v 1.15 2008/09/05 13:44:14 zvision Exp $"
+#define GKSQL_H "@(#) $Id: gksql.h,v 1.17 2009/05/24 20:48:26 willamowius Exp $"
 
 #include <list>
 #include <map>
@@ -266,11 +272,7 @@ public:
 		Info &info /// filled with SQL connection state information upon return
 		);
 		
-#if defined(_WIN32) && (_MSC_VER < 1300)
-public:
-#else
 protected:
-#endif
 	/** Generic SQL database connection object - should be extended 
 	    by derived classes to include backed specific connection data.
 	*/
