@@ -7,10 +7,19 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: gksql_firebird.cxx,v $
+ * Revision 1.16  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.15  2009/03/04 06:04:36  willamowius
+ * fix using ISC_STATUS for Firebird 2.1 thanks Mounir Lamouri
+ *
+ * Revision 1.14  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.13  2008/11/08 18:31:41  willamowius
  * TODO: replace all isc_interprete() with fb_interpret()
  *
@@ -56,11 +65,6 @@
 
 #if HAS_FIREBIRD
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <cmath>
 #include <ibase.h>
@@ -370,7 +374,7 @@ bool GkIBSQLResult::FetchRow(
 			char errormsg[512];
 			if (errcode == -999) {
 				errcode = status[1];
-				long *pvector = status;
+				ISC_STATUS *pvector = status;
 				// TODO: replace all isc_interprete() with fb_interpret()
 				errormsg[isc_interprete(errormsg, &pvector)] = 0;
 			} else {
@@ -417,7 +421,7 @@ bool GkIBSQLResult::FetchRow(
 			char errormsg[512];
 			if (errcode == -999) {
 				errcode = status[1];
-				long *pvector = status;
+				ISC_STATUS *pvector = status;
 				errormsg[isc_interprete(errormsg, &pvector)] = 0;
 			} else {
 				strcpy(errormsg, "SQL:");
@@ -497,7 +501,7 @@ GkSQLConnection::SQLConnPtr GkIBSQLConnection::CreateNewConnection(
 	
 	isc_attach_database(status, 0, const_cast<char*>(dbname.c_str()), &conn, dpb_offset, &(dpb[0]));
 	if (status[0] == 1 && status[1] != 0) {
-		long *pvector = status;
+		ISC_STATUS *pvector = status;
 		char errormsg[512];
 		errormsg[isc_interprete(errormsg, &pvector)] = 0;
 		PTRACE(2, GetName() << "\tFirebird connection to " << m_username << '@' << dbname 
@@ -530,7 +534,7 @@ GkSQLResult* GkIBSQLConnection::ExecuteQuery(
 	
 	isc_start_transaction(status, &tr, 1, &conn, 0, NULL);
 	if (status[0] == 1 && status[1] != 0) {
-		long *pvector = status;
+		ISC_STATUS *pvector = status;
 		char errormsg[512];
 		errormsg[isc_interprete(errormsg, &pvector)] = 0;
 		return new GkIBSQLResult(status[1], errormsg);
@@ -541,7 +545,7 @@ GkSQLResult* GkIBSQLConnection::ExecuteQuery(
 		long errorcode = isc_sqlcode(status);
 		if (errorcode == -999) {
 			errorcode = status[1];
-			long *pvector = status;
+			ISC_STATUS *pvector = status;
 			errormsg[isc_interprete(errormsg, &pvector)] = 0;
 		} else {
 			strcpy(errormsg, "SQL:");
@@ -562,7 +566,7 @@ GkSQLResult* GkIBSQLConnection::ExecuteQuery(
 		long errorcode = isc_sqlcode(status);
 		if (errorcode == -999) {
 			errorcode = status[1];
-			long *pvector = status;
+			ISC_STATUS *pvector = status;
 			errormsg[isc_interprete(errormsg, &pvector)] = 0;
 		} else {
 			strcpy(errormsg, "SQL:");
@@ -585,7 +589,7 @@ GkSQLResult* GkIBSQLConnection::ExecuteQuery(
 			long errorcode = isc_sqlcode(status);
 			if (errorcode == -999) {
 				errorcode = status[1];
-				long *pvector = status;
+				ISC_STATUS *pvector = status;
 				errormsg[isc_interprete(errormsg, &pvector)] = 0;
 			} else {
 				strcpy(errormsg, "SQL:");
@@ -603,7 +607,7 @@ GkSQLResult* GkIBSQLConnection::ExecuteQuery(
 		long errorcode = isc_sqlcode(status);
 		if (errorcode == -999) {
 			errorcode = status[1];
-			long *pvector = status;
+			ISC_STATUS *pvector = status;
 			errormsg[isc_interprete(errormsg, &pvector)] = 0;
 		} else {
 			strcpy(errormsg, "SQL:");
