@@ -7,10 +7,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: gksql_mysql.cxx,v $
+ * Revision 1.17  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.16  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.15  2008/06/27 11:55:03  willamowius
  * allow mutiple results per query from MySQL
  *
@@ -59,11 +65,6 @@
 
 #if HAS_MYSQL
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
-
 #ifdef _WIN32
 #pragma comment( lib, MYSQL_LIBRARY )
 #endif
