@@ -7,10 +7,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: gktimer.h,v $
+ * Revision 1.6  2009/02/09 15:26:21  willamowius
+ * virtual destructors
+ *
+ * Revision 1.5  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.4  2006/04/14 13:56:19  willamowius
  * call failover code merged
  *
@@ -34,7 +40,7 @@
  *
  */
 #ifndef GKTIMER_H
-#define GKTIMER_H "@(#) $Id: gktimer.h,v 1.4 2006/04/14 13:56:19 willamowius Exp $"
+#define GKTIMER_H "@(#) $Id: gktimer.h,v 1.6 2009/02/09 15:26:21 willamowius Exp $"
 
 #include <list>
 
@@ -351,7 +357,7 @@ public:
 	*/
 	void CheckTimers();
 
-	~GkTimerManager();
+	virtual ~GkTimerManager();
 		
 private:
 	GkTimerManager(const GkTimerManager&);
