@@ -4,14 +4,14 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 //////////////////////////////////////////////////////////////////
 
 
 #ifndef H323UTIL_H
-#define H323UTIL_H "@(#) $Id: h323util.h,v 1.25 2008/04/04 08:17:57 shorne Exp $"
+#define H323UTIL_H "@(#) $Id: h323util.h,v 1.27 2009/04/20 09:28:49 willamowius Exp $"
 
 #include <ptlib/sockets.h>
 
@@ -21,6 +21,8 @@ class H225_TransportAddress_ipAddress;
 class H225_EndpointType;
 class H225_AliasAddress;
 class H225_ArrayOf_AliasAddress;
+class H245_TransportAddress;
+class H245_UnicastAddress_iPAddress;
 class PASN_OctetString;
 
 PString AsString(const PIPSocket::Address &, WORD);
@@ -41,6 +43,13 @@ PString AsString(const PASN_OctetString & Octets);
 
 PString StripAliasType(const PString & alias);
 
+H245_UnicastAddress_iPAddress IPToH245TransportIPAddr(const PIPSocket::Address & ip, WORD Port);
+
+H245_TransportAddress IPToH245TransportAddr(const PIPSocket::Address & ip, WORD Port);
+
+// convert a string (dot notation without port) into an H245 transport address
+//H245_TransportAddress StringToH245TransportAddr(const PString & Addr, WORD Port);
+
 // convert a socket IP address into an H225 transport address
 H225_TransportAddress SocketToH225TransportAddr(const PIPSocket::Address & Addr, WORD Port);
 
