@@ -8,7 +8,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chin-Wei Huang <cwhuang@linux.org.tw>
@@ -17,7 +17,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef JOB_H
-#define JOB_H "@(#) $Id: job.h,v 1.10 2008/07/23 13:02:17 willamowius Exp $"
+#define JOB_H "@(#) $Id: job.h,v 1.12 2009/05/28 11:00:07 willamowius Exp $"
 
 #include "name.h"
 
@@ -146,6 +146,7 @@ class RegularJob : public Job
 {
 public:
 	RegularJob();
+	virtual ~RegularJob() {}
 
 	/** @return
 		true if the job has not been yet stopped
