@@ -8,10 +8,19 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: radauth.cxx,v $
+ * Revision 1.49  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.48  2009/05/19 14:38:07  willamowius
+ * codec filtering
+ *
+ * Revision 1.47  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.46  2008/09/15 08:42:09  zvision
  * Allow outbound number rewrite by SQL/RADIUS modules
  *
@@ -226,10 +235,6 @@
 
 #if HAS_RADIUS
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#endif
-
 #include <vector>
 #include <ptlib.h>
 #include <h225ras.h>
@@ -728,6 +733,24 @@ int RadAuthBase::Check(
 			}
 		}
 	}
+	// process h323-ivr-in=codec-disable attribute 
+	if (result) {
+		attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, RadiusAttr::CiscoVSA_AV_Pair);
+		while (attr != NULL) {
+			PINDEX index;
+			value = attr->AsCiscoString();
+			if (value.Find("h323-ivr-in=") == 0 && ((index = value.Find("codec-disable:")) != P_MAX_INDEX)) {
+				index += strlen("codec-disable:");
+				const PINDEX semicolonpos = value.FindLast(';', index);
+				value = value.Mid(index, semicolonpos == P_MAX_INDEX ? P_MAX_INDEX : (semicolonpos-index));
+				PTRACE(4, "RADAUTH\t" << GetName() << " Setup check set codec-disable: " << value); 
+				authData.m_disabledcodecs = value;
+				break;
+			}
+			attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, 
+			RadiusAttr::CiscoVSA_AV_Pair, attr);
+		}
+	}
 	// check for h323-credit-time attribute (call duration limit)	
 	if (result) {
 		attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, 
@@ -1050,6 +1073,24 @@ int RadAuthBase::Check(
 			}
 		}
 	}
+	// process h323-ivr-in=codec-disable attribute
+	if (result) {
+		attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, RadiusAttr::CiscoVSA_AV_Pair);
+		while (attr != NULL) {
+			PINDEX index;
+			value = attr->AsCiscoString();
+			if (value.Find("h323-ivr-in=") == 0 && ((index = value.Find("codec-disable:")) != P_MAX_INDEX)) {
+				index += strlen("codec-disable:");
+				const PINDEX semicolonpos = value.FindLast(';', index);
+				value = value.Mid(index, semicolonpos == P_MAX_INDEX ? P_MAX_INDEX : (semicolonpos-index));
+				PTRACE(4, "RADAUTH\t" << GetName() << " Setup check set codec-disable: " << value); 
+				authData.m_disabledcodecs = value;
+				break;
+			}
+			attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, 
+			RadiusAttr::CiscoVSA_AV_Pair, attr);
+		}
+	}
 	// check for h323-credit-time attribute (call duration limit)	
 	if (result) {
 		attr = response->FindVsaAttr(RadiusAttr::CiscoVendorId, 
