@@ -7,10 +7,19 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: radproto.cxx,v $
+ * Revision 1.45  2009/05/28 10:08:16  willamowius
+ * use the more portable ios::fmtflags instead of _Ios_Fmtflags
+ *
+ * Revision 1.44  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.43  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.42  2008/12/03 18:52:49  willamowius
  * new RadAcct attribute: RewriteE164 (thanks Tusar)
  *
@@ -187,10 +196,6 @@
 
 #if HAS_RADIUS
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include <ptclib/cypher.h>
 #include <ptclib/random.h>
@@ -570,7 +575,7 @@ void RadiusAttr::PrintOn(
 	if (!IsValid()) {
 		strm << "(Invalid) {\n";
 		if (m_length > 0) {
-			const _Ios_Fmtflags flags = strm.flags();
+			const ios::fmtflags flags = strm.flags();
 			const PBYTEArray value((const BYTE*)m_data, m_length, FALSE);
 
 			strm << hex << setfill('0') << resetiosflags(ios::floatfield)
@@ -604,7 +609,7 @@ void RadiusAttr::PrintOn(
 	strm << setw(indent+9) << "length = " << totalLen << " octets\n";
 	
 	if (!IsVsa()) {
-		const _Ios_Fmtflags flags = strm.flags();
+		const ios::fmtflags flags = strm.flags();
 		const PINDEX valueLen = (totalLen <= FixedHeaderLength) 
 			? 0 : (totalLen - FixedHeaderLength);
 		const PBYTEArray value((const BYTE*)m_value, valueLen, FALSE);
@@ -630,7 +635,7 @@ void RadiusAttr::PrintOn(
 		strm << setw(indent+11) << "vendorId = " 
 			<< GetVsaVendorId() << '\n';
 
-		const _Ios_Fmtflags flags = strm.flags();
+		const ios::fmtflags flags = strm.flags();
 		PINDEX valueLen = (totalLen <= VsaFixedHeaderLength)
 			? 0 : (totalLen - VsaFixedHeaderLength);
 		PINDEX headerLen = VsaFixedHeaderLength;
@@ -867,7 +872,7 @@ void RadiusPDU::PrintOn(
 	strm << setw(indent+5) << "id = " << (unsigned)m_id << '\n';
 	strm << setw(indent+9) << "length = " << GetLength() << " octets\n";
 
-	const _Ios_Fmtflags flags = strm.flags();
+	const ios::fmtflags flags = strm.flags();
 	const PBYTEArray value((const BYTE*)m_authenticator, AuthenticatorLength, FALSE);
 
 	strm << setw(indent+28) << "authenticator = 16 octets {\n";
