@@ -8,10 +8,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: radproto.h,v $
+ * Revision 1.22  2009/04/13 12:00:29  willamowius
+ * fix gcc warning
+ *
+ * Revision 1.21  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.20  2008/12/03 18:52:49  willamowius
  * new RadAcct attribute: RewriteE164 (thanks Tusar)
  *
@@ -108,7 +114,7 @@
 #if HAS_RADIUS
 
 #ifndef __RADPROTO_H
-#define __RADPROTO_H "@(#) $Id: radproto.h,v 1.20 2008/12/03 18:52:49 willamowius Exp $"
+#define __RADPROTO_H "@(#) $Id: radproto.h,v 1.22 2009/04/13 12:00:29 willamowius Exp $"
 
 #include <vector>
 #include <ptlib/sockets.h>
@@ -1341,7 +1347,7 @@ protected:
 	typedef std::list<RadiusSocket*>::const_iterator socket_const_iterator;
 	
 	/// An entry describing a signle radius server
-	typedef struct RadiusServer
+	struct RadiusServer
 	{
 		PString m_serverAddress; /// IP or DNS name
 		PString m_sharedSecret; /// password shared between the client and the server
