@@ -7,10 +7,10 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
- * @(#) $Id: sigmsg.cxx,v 1.5 2007/10/29 01:39:33 willamowius Exp $
+ * @(#) $Id: sigmsg.cxx,v 1.7 2009/04/20 09:28:49 willamowius Exp $
  */
 #include <ptlib.h>
 #include <ptlib/sockets.h>
@@ -94,9 +94,7 @@ void SignalingMsg::GetPeerAddr(
 	addr = m_peerAddr;
 }
 
-bool SignalingMsg::Encode(
-	PBYTEArray &buffer
-	)
+bool SignalingMsg::Encode(PBYTEArray &buffer)
 {
 	if (m_uuie != NULL && m_uuieChanged) {
 		PPER_Stream strm;
@@ -107,6 +105,11 @@ bool SignalingMsg::Encode(
 	return m_q931->Encode(buffer) ? true : false;
 }
 
+bool SignalingMsg::Decode(const PBYTEArray & buffer)
+{
+	return m_q931->Decode(buffer) ? true : false;
+}
+
 SignalingMsg* SignalingMsg::Create(
 	Q931 *q931pdu, /// this pointer is not cloned and deleted by this class destructor
 	H225_H323_UserInformation *uuie, /// decoded User-User IE
