@@ -7,10 +7,13 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: sqlacct.h,v $
+ * Revision 1.9  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.8  2008/09/05 13:44:14  zvision
  * GetInfo implemented for SQL acct/auth modules
  *
@@ -43,7 +46,7 @@
  *
  */
 #ifndef SQLACCT_H
-#define SQLACCT_H "@(#) $Id: sqlacct.h,v 1.8 2008/09/05 13:44:14 zvision Exp $"
+#define SQLACCT_H "@(#) $Id: sqlacct.h,v 1.9 2009/02/09 13:25:59 willamowius Exp $"
 
 #include "gkacct.h"
 
