@@ -3,19 +3,15 @@
  *
  * SQL authentication/authorization modules for GNU Gatekeeper
  *
- * $Id: sqlauth.cxx,v 1.19 2008/11/19 12:47:55 zvision Exp $
+ * $Id: sqlauth.cxx,v 1.21 2009/05/24 20:48:26 willamowius Exp $
  *
  * Copyright (c) 2004, Michal Zygmuntowicz
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  */
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
-#endif
 
 #include <ptlib.h>
 #include <h235.h>
