@@ -7,10 +7,16 @@
  *
  * This work is published under the GNU Public License (GPL)
  * see file COPYING for details.
- * We also explicitely grant the right to link this code
+ * We also explicitly grant the right to link this code
  * with the OpenH323 library.
  *
  * $Log: statusacct.cxx,v $
+ * Revision 1.7  2009/05/24 20:48:26  willamowius
+ * remove hacks for VC6 which isn't supported any more since quite a while
+ *
+ * Revision 1.6  2009/02/09 13:25:59  willamowius
+ * typo in comment
+ *
  * Revision 1.5  2007/09/04 15:34:44  willamowius
  * output callID in same format as other status port events (spaces replaced with dashes)
  *
@@ -35,10 +41,6 @@
  *
  */
 
-#if (_MSC_VER >= 1200)
-#pragma warning( disable : 4786 ) // warning about too long debug symbols off
-#endif
-
 #include <ptlib.h>
 #include <h323pdu.h>
 #include "GkStatus.h"
