@@ -6,7 +6,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chih-Wei Huang <cwhuang@linux.org.tw>
@@ -14,10 +14,6 @@
 //
 //////////////////////////////////////////////////////////////////
 
-#if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4284)
-#endif
-
 #include <ptlib.h>
 #include "h323util.h"
 #include "stl_supp.h"
