@@ -6,7 +6,7 @@
 //
 // This work is published under the GNU Public License (GPL)
 // see file COPYING for details.
-// We also explicitely grant the right to link this code
+// We also explicitly grant the right to link this code
 // with the OpenH323 library.
 //
 // initial author: Chin-Wei Huang <cwhuang@linux.org.tw>
@@ -15,7 +15,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef YASOCKET_H
-#define YASOCKET_H "@(#) $Id: yasocket.h,v 1.31 2008/04/25 02:51:56 shorne Exp $"
+#define YASOCKET_H "@(#) $Id: yasocket.h,v 1.34 2009/05/28 11:00:07 willamowius Exp $"
 
 #include <list>
 #include <vector>
@@ -92,6 +92,7 @@ protected:
 class YaTCPSocket : public YaSocket {
 public:
 	YaTCPSocket(WORD = 0);
+	virtual ~YaTCPSocket() {}
 
 	void GetPeerAddress(Address &) const;
 	void GetPeerAddress(Address &, WORD &) const;
@@ -234,9 +235,9 @@ public:
 		Read,
 		Write
 	};
-	SocketSelectList(size_t) {};
+	SocketSelectList(size_t) {}
 	SocketSelectList(PIPSocket *s = 0) { if (s && s->IsOpen()) Append(s); }
-	SocketSelectList(const PString &name, size_t) : m_name(name) {};
+	SocketSelectList(const PString &name, size_t) : m_name(name) {}
 	SocketSelectList(const PString &name, PIPSocket *s = NULL) : m_name(name) { if (s && s->IsOpen()) Append(s); }
 	bool Select(SelectType, const PTimeInterval &);
 	PSocket *operator[](int i) const;
@@ -267,6 +268,8 @@ public:
 	PCLASSINFO( UDPSocket, PUDPSocket )
 	
 	UDPSocket() {}
+	virtual ~UDPSocket() {}
+
 	// override from class PIPSocket
 	PString GetName() const { return (const char *)NamedObject::GetName(); }
 	
@@ -434,6 +437,7 @@ class ServerSocket : public TCPSocket {
 #endif
 public:
 	ServerSocket(WORD pt = 0) : TCPSocket(pt) {}
+	virtual ~ServerSocket() {}
 
 	// new virtual function
 
